@@ -41,6 +41,8 @@ Set::Infinite::Basic is a Set Theory module for infinite sets.
 
 It works on reals, integers, and objects.
 
+This module does not support recurrences. Recurrences are implemented in Set::Infinite.
+
 =head1 METHODS
 
 =cut
@@ -53,12 +55,11 @@ use overload
 
 
 #  _simple_* - an interval of 2 scalars
-
-our $simple_null =           undef;  
-our $simple_everything =     _simple_fastnew(-$inf,  $inf, 1, 1);
-our $simple_inf =            _simple_fastnew( $inf,  $inf, 1, 1);
-our $simple_minus_inf =      _simple_fastnew(-$inf, -$inf, 1, 1);
-
+use vars qw( $simple_null $simple_everything $simple_inf $simple_minus_inf );
+$simple_null =           undef;  
+$simple_everything =     _simple_fastnew(-$inf,  $inf, 1, 1);
+$simple_inf =            _simple_fastnew( $inf,  $inf, 1, 1);
+$simple_minus_inf =      _simple_fastnew(-$inf, -$inf, 1, 1);
 sub _simple_null () { undef }
 
 # TODO: make this an object _and_ class method
@@ -406,6 +407,7 @@ sub iterate {
     my $subroutine = shift;
     foreach $ia (0 .. $#{$a->{list}}) {
         $tmp = &{$subroutine} ( $a->new($a->{list}->[$ia]) );
+        # warn "iterate add ". $tmp->min->ymd;
         $iterate = $iterate->union($tmp) if defined $tmp; 
     }
     return $iterate;    
@@ -683,16 +685,15 @@ sub new {
     my ($self) = bless { list => [] }, $class_name;
     # set up private variables
     if (ref($class)) {
-        $self->{tolerance} = $class->{tolerance}; # if $class->{tolerance};
-        $self->{type}      = $class->{type};      # if $class->{type};
-        $self->{fixtype}   = $class->{fixtype};   # if $class->{fixtype};
+        $self->{tolerance} = $class->{tolerance};
+        $self->{type}      = $class->{type};    
+        $self->{fixtype}   = $class->{fixtype};
     }
     else {
         $self->{tolerance} = $tolerance ? $tolerance : 0;
         $self->{type} =      $class_name->type;
         $self->{fixtype} =   $fixtype   ? $fixtype : 0;
     }
-
     my ($tmp, $tmp2, $ref);
     while (@_) {
         # return $self unless @_;
@@ -700,7 +701,7 @@ sub new {
         $ref = ref($tmp);
         if ($ref) {
             if ($ref eq 'ARRAY') {
-                # Allows arrays of arrays
+                # allows arrays of arrays
                 $tmp = $class->new(@{$tmp});  # call new() recursively
                 push @{ $self->{list} }, @{$tmp->{list}};
                 next;
@@ -775,7 +776,6 @@ sub max_a {
 sub size { 
     my ($self) = shift;
     my $tmp;
-
     my $size = 0;
     foreach(0 .. $#{$self->{list}}) {
         # next unless defined $self->{list}->[$_];
@@ -799,7 +799,6 @@ sub span {
 
 sub spaceship {
     my ($tmp1, $tmp2, $inverted) = @_;
-
     if ($inverted) {
         ($tmp2, $tmp1) = ($tmp1, $tmp2);
     }
@@ -960,6 +959,34 @@ __END__
         Will be interpreted as [1..2],3 instead of [1,2,3].
         You probably want ->new(1,3) instead.
 
+=head1 INTERNALS
+
+The internal representation of a 'span' is a hash:
+
+    { a =>   start of span,
+      b =>   end of span,
+      open_begin =>   '0' the span starts in 'a'
+                      '1' the span starts after 'a'
+      open_end =>     '0' the span ends in 'b'
+                      '1' the span ends before 'b'
+    }
+
+For example, this set:
+
+    [100..200),300,(400..infinity)
+
+is represented by the array of hashes:
+
+    list => [
+        { a => 100, b => 200, open_begin => 0, open_end => 1 },
+        { a => 300, b => 300, open_begin => 0, open_end => 0 },
+        { a => 400, b => infinity, open_begin => 0, open_end => 1 },
+    ]
+
+The infinity value is generated by Perl, when it finds a numerical overflow:
+
+    $inf = 100**100**100;
+
 =head1 SEE ALSO
 
     Set::Infinite
